--[[
## Interface: 50001
## Title: BalancePowerTracker_Options
## Version: 1.1.1
## Author: Kurohoshi (EU-Minahonda)
## Notes: BPT's Options. /bpt or /balancepowertracker to show.

--CHANGELOG
v1.1.1 MoP release
--]]

local function CreateOptions(_,_,name) 
	if name~= "BalancePowerTracker_Options" then
		return 
	end
	
	if not BalancePowerTracker then 
		print("|c00a080ffBalancePowerTracker Options|r: LOADING ERROR: BalancePowerTracker not found") 
		return 
	end
	
	local class = select(2,UnitClass("player"))
	
	local me = {}
	local opt = BalancePowerTracker_Options
	local BPT = BalancePowerTracker
	BalancePowerTracker_Options = BalancePowerTracker_Options or {}
	
	local Propagate = BPT.CheckAll or function() return "Not found." end 
	local modules = (BPT and BPT.modules) or {}

	local function switch(t,key)
		t[key] = not t[key]
		Propagate()
	end
	
	me.data = {
		statusbar = {
			["Interface\\TARGETINGFRAME\\UI-TargetingFrame-BarFill"] = "UI TargetingFrame BarFill",
		},
		border = {
			["Interface\\Tooltips\\UI-Tooltip-Border"] = "UI Tooltip Border", 
		},
		sound = {
			["Interface\\Quiet.ogg"] = "silent",
		},
		font = {
			["Fonts\\FRIZQT__.TTF"] = "BPT default",
		},
	}
	
	-- Libsharedmedia
	local media = LibStub and LibStub:GetLibrary("LibSharedMedia-3.0",true);
	function me.LibSharedMedia_Registered()
		if not media then return end
		
		for k in pairs(me.data) do
			for _, name in pairs(media:List(k)) do
				local path = media:Fetch(k, name)
				if path then
					me.data[k][path] = name
				end
			end
		end
	end
	if media then 
		media.RegisterCallback(me, "LibSharedMedia_Registered")
		me.LibSharedMedia_Registered()
	end
	
	local strata ={
		"BACKGROUND",
		"LOW",
		"MEDIUM",
		"HIGH",
		"DIALOG",
		"FULLSCREEN",
		"FULLSCREEN_DIALOG",
		"TOOLTIP",
	}
	
	local points = {
	    TOPLEFT = "TOPLEFT",
		TOPRIGHT = "TOPRIGHT",
		BOTTOMLEFT = "BOTTOMLEFT",
		BOTTOMRIGHT = "BOTTOMRIGHT",
		TOP = "TOP",
		BOTTOM = "BOTTOM",
		LEFT = "LEFT",
		RIGHT = "RIGHT",
		CENTER  = "CENTER",
	}
	
	local function searchKey(t,value)
		for k,v in pairs(t) do
			if v==value then
				return k
			end
		end
	end
	
	local function alertOption(key,name,order)
		return {
			name	= name,
			type	= 'group',
			order	= order,
			args	= {
					showText	= {
						type	= 'toggle',
						name	= 'Show text',
						get		= function () return opt.warning_text[key].warnThis end,
						set		= function () switch(opt.warning_text[key],"warnThis") end,
						order	= 1,
					},
					text	= {
						type	= 'input',
						name	= "Text shown",
						disabled= function () return not opt.warning_text[key].warnThis end, 
						get		= function () return opt.warning_text[key].text end,
						set		= function(_,new) opt.warning_text[key].text= new end,
						order	= 2,
					},
					playSound	= {
						type	= 'toggle',
						name	= 'Play sound',
						get		= function () return opt.warning_text[key].playThis end,
						set		= function () switch(opt.warning_text[key],"playThis") end,
						order	= 3,
					},
					sound	= {
						type	= 'select',
						name	= "Alert sound",
						disabled= function () return not opt.warning_text[key].playThis end, 
						get		= function () return opt.warning_text[key].sound; end,
						set		= function(_,new) opt.warning_text[key].sound=new; PlaySoundFile(new) end,
						values	= function () return me.data.sound end,
						order	= 4,
					},
					FlashThis	= {
						type	= 'toggle',
						name	= 'Flash screen',
						get		= function () return opt.warning_text[key].flashThis end,
						set		= function () switch(opt.warning_text[key],"flashThis") end,
						order	= 5,
					},
					color	= {
						type = 'color',
						name = "Solar Color",
						hasAlpha = true,
						desc = nil,
						get	= function ()local color = opt.warning_text[key].color ;return color.r, color.g, color.b, color.a end,
						set	= function (info, r, g, b, a)local color = opt.warning_text[key].color;color.r=r color.g=g color.b=b color.a=a Propagate() end,
						order	= 6,
					},
					MSBTThis	= {
						type	= 'toggle',
						name	= 'MikSBT alert',
						hidden = function() return not MikSBT end,
						get		= function () return opt.warning_text[key].MSBTThis end,
						set		= function () switch(opt.warning_text[key],"MSBTThis") end,
						order	= 7,
					},
					showTexture	= {
						type	= 'toggle',
						name	= 'Show texture',
						desc 	= 'Show texture in MikSBT alert',
						hidden = function() return not (MikSBT and opt.warning_text[key].MSBTThis) end,
						get		= function () return opt.warning_text[key].showTexture end,
						set		= function () switch(opt.warning_text[key],"showTexture") end,
						order	= 8,
					},
					texture = {
						type = "input",
						name	= 'Texture shown',
						hidden = function() return not (MikSBT and opt.warning_text[key].MSBTThis and opt.warning_text[key].showTexture) end,
						get		= function () return opt.warning_text[key].texture end,
						set		= function(_,new) opt.warning_text[key].texture= new end,
						width	= "full",
						order = 9,
					},
					displaytexture = {
						type = "description",
						name = 'Texture',
						image = function() return opt.warning_text[key].texture end,
						hidden = function() return not (MikSBT and opt.warning_text[key].MSBTThis and opt.warning_text[key].showTexture) end,
						order = 10
					},
			},
		}
	end
	
	local options = { 
		name	= BalancePowerTracker.name.." v"..GetAddOnMetadata(BalancePowerTracker.name, "Version"),
		type	= 'group',
		args	= {
			reset	= {
				type	= 'execute',
				name	= "Reset all",
				confirm = true,
				confirmText = "Reset cannot be undone",
				desc	= "Reset to default",
				func	= function () 
							BalancePowerTracker_Options = nil; 
							local text = "|c00a080ffBalancePowerTracker|r: "
							local err = Propagate(); 
							opt = BalancePowerTracker_Options
							if err then 
								text=text..err
							else 
								text=text.."Reset done."
							end
							print(text) 
						end,
				order	= 2,
			},
			verbose = {
				type	= 'toggle',
				name	= "Silent load",
				desc	= "Don't show message when successfully loaded",
				get		= function () return opt.global.muted end,
				set		= function () switch(opt.global,"muted") end,
				order	= 3,
			},
			Modules = {
			    type	= 'group',
				name	= "Modules",
				order	= 5,
				args ={
					header = {
						type	= 'header',
						name    = "Toogle ON/OFF each module:",
						order = 3,
					},
					eclipse_bar = {
						type	= 'toggle',
						name	= "Eclipse bar",
						desc	= "Enable/Disable the eclipse bar.",
						hidden	= function() return (not modules.eclipse_bar) or (modules.eclipse_bar.class and not modules.eclipse_bar.class[class]) end,
						get		= function () return opt.eclipse_bar.load end,
						set		= function () switch(opt.eclipse_bar,"load") end,
						order	= 4,
					},
					warning_text = {
						type	= 'toggle',
						name	= "Alerts",
						desc	= "Enable/Disable the alerts.",
						hidden	= function() return (not modules.warning_text) or (modules.warning_text.class and not modules.warning_text.class[class]) end,
						get		= function () return opt.warning_text.load end,
						set		= function () switch(opt.warning_text,"load") end,
						order	= 12,
					},
					hide_default = {
						type	= 'toggle',
						name	= "Hide default Eclipse bar",
						desc	= "Hide/show default eclipse bar.",
						hidden	= function() return (not modules.hide_default) or (modules.hide_default.class and not modules.hide_default.class[class]) end,
						get		= function () return opt.hide_default.load end,
						set		= function () switch(opt.hide_default,"load") end,
						order	= 16,
					},
					default_art = {
						type	= 'toggle',
						name	= "Default art Eclipse bar",
						desc	= "Shows another eclipse bar with the default art and very reduced options",
						hidden	= function() return (not modules.default_art) or (modules.default_art.class and not modules.default_art.class[class]) end,
						get		= function () return opt.default_art.load end,
						set		= function () switch(opt.default_art,"load") end,
						order	= 20,
					},
					pipe = {
						type	= 'toggle',
						name	= "Pipe",
						desc	= "Tries to convince other addons and the UI to use predicted values instead of the real ones. CAN CAUSE TAINT ISSUES AND IS NOT GUARANTEED TO WORK: LEAVE UNCHECKED UNLESS YOU REALLY NEED IT",
						hidden	= function() return (not modules.pipe) or (modules.pipe.class and not modules.pipe.class[class]) end,
						get		= function () return opt.pipe.load end,
						set		= function () switch(opt.pipe,"load") end,
						order	= 24,
					},
				},
			},
			Warning = {
			    type	= 'group',
				name	= "Alerts",
				order	= 10,
				disabled = function() return not (modules.warning_text and modules.warning_text.loaded and opt and opt.warning_text) end,
				hidden	= function() return (not modules.warning_text) or (modules.warning_text.class and not modules.warning_text.class[class]) end,
				args ={
					reset	= {
						type	= 'execute',
						name	= "Reset alert",
						confirm = true,
						confirmText = "Reset cannot be undone",
						desc	= "Reset alert settings",
						func	= function () opt.warning_text = nil; Propagate(); end,
						order	= 1,
					},
					move	= {
						type	= 'toggle',
						name	= 'Move freely',
						desc	= "Move the alerts text by dragging it",
						get		= function () return opt.warning_text.testing end,
						set		= function () switch(opt.warning_text,"testing") end,
						order	= 2,
					},
					x	= {
						type	= 'range',
						name	= "X",
						desc	= nil,
						min		= -900,
						max		= 900,
						step    = 1,
						get		= function () return opt.warning_text.x end,
						set		= function (_, new) opt.warning_text.x = new; Propagate() end,
						order	= 3,
					},
					y	= {
						type = 'range',
						name = "Y",
						desc = nil,
						min	= -600,
						max	= 600,
						step = 1,
						get		= function () return opt.warning_text.y end,
						set		= function (_, new) opt.warning_text.y = new; Propagate() end,
						order = 4,
					},
					point	= {
						type	= 'select',
						name	= "Anchor point",
						get		= function () return opt.warning_text.point; end,
						set		= function(_,new) opt.warning_text.point=new; Propagate() end,
						values	= function () return points end,
						order	= 5,
					},
					scale	= {
						type = 'range',
						name = "Scale",
						desc = nil,
						min	= 0.5,
						max	= 4,
						step = 0.05,
						get		= function () return opt.warning_text.scale end,
						set		= function (_, new) opt.warning_text.scale = new; Propagate() end,
						order = 6,
					},
					flashAlpha	= {
						type = 'range',
						name = "Flash alpha",
						desc = nil,
						min	= 0,
						max	= 1,
						step = 0.05,
						get		= function () return opt.warning_text.flashAlpha end,
						set		= function (_, new) opt.warning_text.flashAlpha = new; Propagate() end,
						order = 7,
					},
					spellEffects	= {
						type	= 'toggle',
						name	= 'Spell effects',
						desc	= "Show the spell effects (sun and moon above yout char) when predicting Eclipse",
						get		= function () return opt.warning_text.spellEffects end,
						set		= function () switch(opt.warning_text,"spellEffects") end,
						order	= 8,
					},
					font	= {
						type	= 'select',
						name	= "Alert font",
						get		= function () return opt.warning_text.font; end,
						set		= function(_,new) opt.warning_text.font=new; Propagate() end,
						values	= function () return me.data.font end,
						order	= 9,
					},
					fontSize	= {
						type = 'range',
						name = "Font size",
						desc = nil,
						min	= 10,
						max	= 32,
						step = 1,
						get		= function () return opt.warning_text.fontSize end,
						set		= function (_, new) opt.warning_text.fontSize = new; Propagate() end,
						order = 10,
					},
					SolarEclipse = alertOption("RealSolarEclipse","Solar Eclipse alert options",11),
					LunarEclipse = alertOption("RealLunarEclipse","Lunar Eclipse alert options",12),
					vSolarEclipse = alertOption("PredictedSolarEclipse","Predicted Solar Eclipse alert options",13),
					vLunarEclipse = alertOption("PredictedLunarEclipse","Predicted Lunar Eclipse alert options",14),
					MSBT_sticky	= {
						type	= 'toggle',
						name	= 'MikSBT Sticky',
						hidden	= function() return not MikSBT end,
						desc	= "Make the MikSBT alert sticky",
						get		= function () return opt.warning_text.MSBT_sticky end,
						set		= function () switch(opt.warning_text,"MSBT_sticky") end,
						order	= 15,
					},
					MSBT_outlineIndex	= {
						type = 'range',
						name = "MikSBT Outline Index",
						desc = nil,
						hidden	= function() return not MikSBT end,
						min	= 0,
						max	= 6,
						step = 1,
						get		= function () return opt.warning_text.MSBT_outlineIndex end,
						set		= function (_, new) opt.warning_text.MSBT_outlineIndex = new; end,
						order = 16,
					},
					MSBT_outlineIndex	= {
						type = 'select',
						name = "MikSBT scroll area",
						desc = nil,
						hidden	= function() return not MikSBT end,
						get		= function () return opt.warning_text.MSBT_scrollArea end,
						set		= function (_, new) opt.warning_text.MSBT_scrollArea = new; end,
						values	= function () 
									local ret = {}
									for scrollAreaKey, scrollAreaName in MikSBT.IterateScrollAreas() do
										ret[scrollAreaKey] = scrollAreaName
									end
								
									return ret
								end,
						order = 16,
					},
				},
			},
			eclipse_bar = {
			    type	= 'group',
				name	= "Eclipse Bar",
				order	= 9,
				hidden	= function() return (not modules.eclipse_bar) or (modules.eclipse_bar.class and not modules.eclipse_bar.class[class]) end,
				disabled = function() return not (modules.eclipse_bar and modules.eclipse_bar.loaded and opt and opt.eclipse_bar)end,
				args ={
					reset	= {
						type	= 'execute',
						name	= "Reset eclipse bar",
						confirm = true,
						confirmText = "Reset cannot be undone",
						desc	= "Reset eclipse bar settings",
						func	= function () opt.eclipse_bar = nil; Propagate(); end,
						order	= 1,
					},
					move	= {
						type	= 'toggle',
						name	= 'Move freely',
						desc	= "Move the bar by dragging it",
						get		= function () return opt.eclipse_bar.moving end,
						set		= function () switch(opt.eclipse_bar,"moving") end,
						order	= 2,
					},
					x	= {
						type	= 'range',
						name	= "X",
						desc	= nil,
						min		= -900,
						max		= 900,
						step    = 1,
						get		= function () return opt.eclipse_bar.x end,
						set		= function (_, new) opt.eclipse_bar.x = new; Propagate() end,
						order	= 3,
					},
					y	= {
						type = 'range',
						name = "Y",
						desc = nil,
						min	= -600,
						max	= 600,
						step = 1,
						get		= function () return opt.eclipse_bar.y end,
						set		= function (_, new) opt.eclipse_bar.y = new; Propagate() end,
						order = 4,
					},
					point	= {
						type	= 'select',
						name	= "Anchor point",
						get		= function () return opt.eclipse_bar.point; end,
						set		= function(_,new) opt.eclipse_bar.point=new; Propagate() end,
						values	= function () return points end,
						order	= 5,
					},
					strata	= {
						type	= 'select',
						name	= "Layer",
						get		= function () return searchKey(strata,opt.eclipse_bar.strata); end,
						set		= function(_,new) opt.eclipse_bar.strata=strata[new]; Propagate() end,
						values	= function () return strata end,
						order	= 6,
					},
					height	= {
						type	= 'range',
						name	= "Height",
						desc	= nil,
						min		= 10,
						max		= 50,
						step    = 1,
						get		= function () return opt.eclipse_bar.height end,
						set		= function (_, new) opt.eclipse_bar.height = new; Propagate() end,
						order	= 7,
					},
					width	= {
						type = 'range',
						name = "Width",
						desc = nil,
						min	= 10,
						max	= 400,
						step = 1,
						get		= function () return opt.eclipse_bar.width end,
						set		= function (_, new) opt.eclipse_bar.width = new; Propagate() end,
						order = 8,
					},
					scale	= {
						type = 'range',
						name = "Scale",
						desc = nil,
						min	= 0.5,
						max	= 4,
						step = 0.05,
						get		= function () return opt.eclipse_bar.scale end,
						set		= function (_, new) opt.eclipse_bar.scale = new; Propagate() end,
						order = 9,
					},
					visibility ={
						name	= "Visibility",
						type	= 'group',
						order	= 11,
						args	= {
							alpha	= {
								type = 'range',
								name = "Alpha",
								desc = nil,
								min	= 0,
								max	= 1,
								step = 0.05,
								get		= function () return opt.eclipse_bar.alpha end,
								set		= function (_, new) opt.eclipse_bar.alpha = new; Propagate() end,
								order = 1,
							},
							alphaOOC	= {
								type = 'range',
								name = "Alpha out of combat",
								desc = nil,
								min	= 0,
								max	= 1,
								step = 0.05,
								get		= function () return opt.eclipse_bar.alphaOOC end,
								set		= function (_, new) opt.eclipse_bar.alphaOOC = new; Propagate() end,
								order = 2,
							},
							showInAll	= {
								type	= 'toggle',
								name	= 'Show in all forms',
								get		= function () return opt.eclipse_bar.showInAllStances end,
								set		= function () switch(opt.eclipse_bar,"showInAllStances") end,
								order	= 3,
							},
							showCustomize	= {
								type	= 'multiselect',
								disabled = function () return opt.eclipse_bar.showInAllStances; end,
								name	= "Customizable show in form",
								get		=	function(_,keyname)	return opt.eclipse_bar.custom[keyname]; end,
								set		= 	function(_,keyname, state)
												opt.eclipse_bar.custom[keyname] = state;
												if keyname == 27 then
													opt.eclipse_bar.custom[29] = state; --normal flight form
												end
												Propagate();
											end,
								values	= function () return {[1]="Cat",[5]="Bear",[31]="Moonkin",[27]="Flight",[3]="Travel",[4]="Aquatic",[0]="Humanoid"} end,
								order	= 4,
							},
						}
					},
					barOptions ={
						name	= "Bar options",
						type	= 'group',
						order	= 12,
						args	= {
							showPredictBar	= {
								type	= 'toggle',
								name	= 'Show predicted energy bar',
								get		= function () return opt.eclipse_bar.showPredictBar end,
								set		= function () switch(opt.eclipse_bar,"showPredictBar") end,
								order	= 1,
							},
							barModeColorAll	= {
								type	= 'toggle',
								name	= 'Color all bar',
								desc	= "Color all bar with arrow's direction color.",
								get		= function () return opt.eclipse_bar.barModeColorAll end,
								set		= function () switch(opt.eclipse_bar,"barModeColorAll") end,
								order	= 2,
							},
							vertical	= {
								type	= 'toggle',
								name	= 'Vertical bar',
								get		= function () return opt.eclipse_bar.vertical end,
								set		= function () switch(opt.eclipse_bar,"vertical") end,
								order	= 10,
							},
							showIcons = {
								type	= 'toggle',
								name	= 'Show Eclipse icons',
								get		= function () return opt.eclipse_bar.showIcons end,
								set		= function () switch(opt.eclipse_bar,"showIcons") end,
								order	= 9,
							},
							gainSpark	= {
								type	= 'toggle',
								name	= 'Energy gain spark',
								desc	= "Spark shows where you cast currently is in the predicted energy bar.",
								get		= function () return opt.eclipse_bar.gainSpark end,
								set		= function () switch(opt.eclipse_bar,"gainSpark") end,
								order	= 4,
							},
							barModeCastBar	= {
								type	= 'toggle',
								name	= 'Castbar mode',
								desc	= "When casting a spell that gives eclipse energy, the spark travels all the bar.",
								get		= function () return opt.eclipse_bar.barModeCastBar end,
								set		= function () switch(opt.eclipse_bar,"barModeCastBar") end,
								order	= 5,
							},
							bartexture	= {
								type	= 'select',
								name	= "Bar texture",
								get		= function () return opt.eclipse_bar.barTextureFile; end,
								set		= function(_,new) opt.eclipse_bar.barTextureFile=new; Propagate() end,
								values	= function () return me.data.statusbar end,
								order	= 6,
							},
							bordertexture	= {
								type	= 'select',
								name	= "Border texture",
								get		= function () return opt.eclipse_bar.edgeFile; end,
								set		= function(_,new) opt.eclipse_bar.edgeFile=new; Propagate() end,
								values	= function () return me.data.border end,
								order	= 7,
							},
						}
					},	
					text ={
						name	= "Arrow & text options",
						type	= 'group',
						order	= 14,
						args	= {
							predictOnArrow	= {
								type	= 'toggle',
								name	= 'Show predicted energy on arrow and text',
								get		= function () return opt.eclipse_bar.predictOnArrow end,
								set		= function () switch(opt.eclipse_bar,"predictOnArrow") end,
								order	= 1,
							},
							arrowscale	= {
								type = 'range',
								name = "Arrow scale",
								desc = nil,
								min	= 0.5,
								max	= 4,
								step = 0.05,
								get		= function () return opt.eclipse_bar.arrowScale end,
								set		= function (_, new) opt.eclipse_bar.arrowScale = new; Propagate() end,
								order = 2,
							},
							
							showValue	= {
								type	= 'toggle',
								name	= 'Show text',
								get		= function () return opt.eclipse_bar.showValue end,
								set		= function () switch(opt.eclipse_bar,"showValue") end,
								order	= 3,
							},
							moveTextOutOfTheWay	= {
								type	= 'toggle',
								name	= 'Move text',
								desc	= "Move text when arrow is over it.",
								disabled = function () return not opt.eclipse_bar.showValue end,
								get		= function () return opt.eclipse_bar.moveTextOutOfTheWay end,
								set		= function () switch(opt.eclipse_bar,"moveTextOutOfTheWay") end,
								order	= 4,
							},
							absoluteText	= {
								type	= 'toggle',
								name	= 'Show always positive values',
								get		= function () return opt.eclipse_bar.absoluteText end,
								disabled = function () return not opt.eclipse_bar.showValue end,
								set		= function () switch(opt.eclipse_bar,"absoluteText") end,
								order	= 5,
							},
							autoFontSize	= {
								type	= 'toggle',
								name	= 'Auto font size',
								get		= function () return opt.eclipse_bar.autoFontSize end,
								disabled = function () return not opt.eclipse_bar.showValue end,
								set		= function () switch(opt.eclipse_bar,"autoFontSize") end,
								order	= 6,
							},
							font	= {
								type	= 'select',
								name	= "Font",
								get		= function () return opt.eclipse_bar.font; end,
								disabled = function () return not opt.eclipse_bar.showValue end,
								set		= function(_,new) opt.eclipse_bar.font=new; Propagate() end,
								values	= function () return me.data.font end,
								order	= 9,
							},
							fontSize	= {
								type = 'range',
								name = "Font size",
								desc = nil,
								min	= 10,
								max	= 32,
								step = 1,
								disabled = function () return (not opt.eclipse_bar.showValue) or opt.eclipse_bar.autoFontSize end,
								get		= function () return opt.eclipse_bar.fontSize end,
								set		= function (_, new) opt.eclipse_bar.fontSize = new; Propagate() end,
								order = 8,
							},
						}
					},	
					
					
					eclipse_icons = {
						type	= 'group',
						name	= "Eclipse Icons",
						order	= 15,
						disabled = function() return not (opt.eclipse_bar.showIcons) end,
						args ={
							sx	= {
								type	= 'range',
								name	= "Solar icon X offset",
								desc	= nil,
								min		= -900,
								max		= 900,
								step    = 1,
								get		= function () return opt.eclipse_bar.sx end,
								set		= function (_, new) opt.eclipse_bar.sx = new; Propagate() end,
								order	= 3,
							},
							sy	= {
								type = 'range',
								name = "Solar icon Y offset",
								desc = nil,
								min	= -600,
								max	= 600,
								step = 1,
								get		= function () return opt.eclipse_bar.sy end,
								set		= function (_, new) opt.eclipse_bar.sy = new; Propagate() end,
								order = 4,
							},
							lx	= {
								type	= 'range',
								name	= "Lunar icon X offset",
								desc	= nil,
								min		= -900,
								max		= 900,
								step    = 1,
								get		= function () return opt.eclipse_bar.lx end,
								set		= function (_, new) opt.eclipse_bar.lx = new; Propagate() end,
								order	= 5,
							},
							ly	= {
								type = 'range',
								name = "Lunar icon Y offset",
								desc = nil,
								min	= -600,
								max	= 600,
								step = 1,
								get		= function () return opt.eclipse_bar.ly end,
								set		= function (_, new) opt.eclipse_bar.ly = new; Propagate() end,
								order = 6,
							},
							size	= {
								type = 'range',
								name = "Icon size",
								desc = nil,
								min	= 10,
								max	= 50,
								step = 1,
								get		= function () return opt.eclipse_bar.iconSize end,
								set		= function (_, new) opt.eclipse_bar.iconSize = new; Propagate() end,
								order = 9,
							},
							predict	= {
								type	= 'toggle',
								name	= 'Use predicted info',
								get		= function () return opt.eclipse_bar.predictOnIcons end,
								set		= function () switch(opt.eclipse_bar,"predictOnIcons") end,
								order	= 14,
							},
							bigIcons	= {
								type	= 'toggle',
								name	= 'Big Icons',
								desc	= "Enlarge nearest Eclipse",
								get		= function () return opt.eclipse_bar.big_icons end,
								set		= function () switch(opt.eclipse_bar,"big_icons") end,
								order	= 15,
							},
							bigscale	= {
								type = 'range',
								name = "Big icons scale",
								desc = nil,
								disabled = function () return not opt.eclipse_bar.big_icons end,
								min	= 0.5,
								max	= 4,
								step = 0.05,
								get		= function () return opt.eclipse_bar.iconBigScale end,
								set		= function (_, new) opt.eclipse_bar.iconBigScale = new; Propagate() end,
								order = 16,
							},
							highlight	= {
								type	= 'select',
								name	= "Highlight type",
								get		= function ()
											if opt.eclipse_bar.iconSpellReady then return 3
											elseif opt.eclipse_bar.iconGlow then return 2
											else return 1
											end
										end,
								set		= function(_,new) 
											opt.eclipse_bar.iconSpellReady = new == 3
											opt.eclipse_bar.iconGlow = new == 2 
											Propagate()
										end,
								values	= function () return {"None","Normal","'Spell ready' effect"} end,
								order	= 17,
							}
						},
					},
					
					
					color ={
						name	= "Color",
						type	= 'group',
						order	= 16,
						args	= {
								solarColor	= {
									type = 'color',
									name = "Solar",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.eclipse_bar.solarColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.eclipse_bar.solarColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 1,
								},
								lunarColor	= {
									type = 'color',
									name = "Lunar",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.eclipse_bar.lunarColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.eclipse_bar.lunarColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 2,
								},
								predictedSolarColor	= {
									type = 'color',
									name = "Predicted Solar",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.eclipse_bar.predictedSolarColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.eclipse_bar.predictedSolarColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 3,
								},
								predictedLunarColor	= {
									type = 'color',
									name = "Predicted Lunar",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.eclipse_bar.predictedLunarColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.eclipse_bar.predictedLunarColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 4,
								},
								textColor	= {
									type = 'color',
									name = "Text",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.eclipse_bar.textColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.eclipse_bar.textColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 5,
								},
								backGroundColor	= {
									type = 'color',
									name = "Background",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.eclipse_bar.backGroundColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.eclipse_bar.backGroundColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 6,
								},
								borderColor	= {
									type = 'color',
									name = "Edge",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.eclipse_bar.borderColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.eclipse_bar.borderColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 7,
								},
						},
					},
				}
			},
			default_art = {
			    type	= 'group',
				name	= "Default art bar",
				order	= 12,
				hidden	= function() return (not modules.default_art) or (modules.default_art.class and not modules.default_art.class[class]) end,
				disabled = function() return not (modules.default_art and modules.default_art.loaded and opt and opt.default_art)end,
				args ={
					reset	= {
						type	= 'execute',
						name	= "Reset eclipse bar",
						confirm = true,
						confirmText = "Reset cannot be undone",
						desc	= "Reset eclipse bar settings",
						func	= function () opt.default_art = nil; Propagate(); end,
						order	= 1,
					},
					move	= {
						type	= 'toggle',
						name	= 'Move freely',
						desc	= "Move the bar by dragging it",
						get		= function () return opt.default_art.moving end,
						set		= function () switch(opt.default_art,"moving") end,
						order	= 2,
					},
					x	= {
						type	= 'range',
						name	= "X",
						desc	= nil,
						min		= -900,
						max		= 900,
						step    = 1,
						get		= function () return opt.default_art.x end,
						set		= function (_, new) opt.default_art.x = new; Propagate() end,
						order	= 3,
					},
					y	= {
						type = 'range',
						name = "Y",
						desc = nil,
						min	= -600,
						max	= 600,
						step = 1,
						get		= function () return opt.default_art.y end,
						set		= function (_, new) opt.default_art.y = new; Propagate() end,
						order = 4,
					},
					point	= {
						type	= 'select',
						name	= "Anchor point",
						get		= function () return opt.default_art.point; end,
						set		= function(_,new) opt.default_art.point=new; Propagate() end,
						values	= function () return points end,
						order	= 5,
					},
					strata	= {
						type	= 'select',
						name	= "Layer",
						get		= function () return searchKey(strata,opt.default_art.strata); end,
						set		= function(_,new) opt.default_art.strata=strata[new]; Propagate() end,
						values	= function () return strata end,
						order	= 6,
					},
					--[[height	= {
						type	= 'range',
						name	= "Height",
						desc	= nil,
						min		= 10,
						max		= 50,
						step    = 1,
						get		= function () return opt.default_art.height end,
						set		= function (_, new) opt.default_art.height = new; Propagate() end,
						order	= 7,
					},
					width	= {
						type = 'range',
						name = "Width",
						desc = nil,
						min	= 10,
						max	= 400,
						step = 1,
						get		= function () return opt.default_art.width end,
						set		= function (_, new) opt.default_art.width = new; Propagate() end,
						order = 8,
					},]]
					scale	= {
						type = 'range',
						name = "Scale",
						desc = nil,
						min	= 0.5,
						max	= 4,
						step = 0.05,
						get		= function () return opt.default_art.scale end,
						set		= function (_, new) opt.default_art.scale = new; Propagate() end,
						order = 9,
					},
					visibility ={
						name	= "Visibility",
						type	= 'group',
						order	= 11,
						args	= {
							alpha	= {
								type = 'range',
								name = "Alpha",
								desc = nil,
								min	= 0,
								max	= 1,
								step = 0.05,
								get		= function () return opt.default_art.alpha end,
								set		= function (_, new) opt.default_art.alpha = new; Propagate() end,
								order = 1,
							},
							alphaOOC	= {
								type = 'range',
								name = "Alpha out of combat",
								desc = nil,
								min	= 0,
								max	= 1,
								step = 0.05,
								get		= function () return opt.default_art.alphaOOC end,
								set		= function (_, new) opt.default_art.alphaOOC = new; Propagate() end,
								order = 2,
							},
							showInAll	= {
								type	= 'toggle',
								name	= 'Show in all forms',
								get		= function () return opt.default_art.showInAllStances end,
								set		= function () switch(opt.default_art,"showInAllStances") end,
								order	= 3,
							},
							showCustomize	= {
								type	= 'multiselect',
								disabled = function () return opt.default_art.showInAllStances; end,
								name	= "Customizable show in form",
								get		=	function(_,keyname)	return opt.default_art.custom[keyname]; end,
								set		= 	function(_,keyname, state)
												opt.default_art.custom[keyname] = state;
												if keyname == 27 then
													opt.default_art.custom[29] = state; --normal flight form
												end
												Propagate();
											end,
								values	= function () return {[1]="Cat",[5]="Bear",[31]="Moonkin",[27]="Flight",[3]="Travel",[4]="Aquatic",[0]="Humanoid"} end,
								order	= 4,
							},
						}
					},
					text ={
						name	= "Arrow & text options",
						type	= 'group',
						order	= 14,
						args	= {
							predictOnArrow	= {
								type	= 'toggle',
								name	= 'Show predicted energy on arrow and text',
								get		= function () return opt.default_art.predict end,
								set		= function () switch(opt.default_art,"predict") end,
								order	= 1,
							},
							showValue	= {
								type	= 'toggle',
								name	= 'Show text',
								get		= function () return opt.default_art.showValue end,
								set		= function () switch(opt.default_art,"showValue") end,
								order	= 3,
							},
							moveTextOutOfTheWay	= {
								type	= 'toggle',
								name	= 'Move text',
								desc	= "Move text when arrow is over it.",
								disabled = function () return not opt.default_art.showValue end,
								get		= function () return opt.default_art.moveTextOutOfTheWay end,
								set		= function () switch(opt.default_art,"moveTextOutOfTheWay") end,
								order	= 4,
							},
							absoluteText	= {
								type	= 'toggle',
								name	= 'Show always positive values',
								get		= function () return opt.default_art.absoluteText end,
								disabled = function () return not opt.default_art.showValue end,
								set		= function () switch(opt.default_art,"absoluteText") end,
								order	= 5,
							},
							autoFontSize	= {
								type	= 'toggle',
								name	= 'Auto font size',
								get		= function () return opt.default_art.autoFontSize end,
								disabled = function () return not opt.default_art.showValue end,
								set		= function () switch(opt.default_art,"autoFontSize") end,
								order	= 6,
							},
							font	= {
								type	= 'select',
								name	= "Font",
								get		= function () return opt.default_art.font; end,
								disabled = function () return not opt.default_art.showValue end,
								set		= function(_,new) opt.default_art.font=new; Propagate() end,
								values	= function () return me.data.font end,
								order	= 9,
							},
							fontSize	= {
								type = 'range',
								name = "Font size",
								desc = nil,
								min	= 10,
								max	= 32,
								step = 1,
								disabled = function () return (not opt.default_art.showValue) or opt.default_art.autoFontSize end,
								get		= function () return opt.default_art.fontSize end,
								set		= function (_, new) opt.default_art.fontSize = new; Propagate() end,
								order = 8,
							},
						}
					},	
					color ={
						name	= "Color",
						type	= 'group',
						order	= 15,
						args	= {
								textColor	= {
									type = 'color',
									name = "Text",
									hasAlpha = true,
									desc = nil,
									get	= function ()local color = opt.default_art.textColor ;return color.r, color.g, color.b, color.a end,
									set	= function (info, r, g, b, a)local color = opt.default_art.textColor;color.r=r color.g=g color.b=b color.a=a Propagate() end,
									order	= 5,
								},
						},
					},
				}
			},
			Info = {
			    type	= 'group',
				name	= "Info",
				order	= 4,
				args ={
					header = {
						type	= 'header',
						name    =BalancePowerTracker.name,
						order = 1,
					},
					info1 = {
						type	= 'description',
						name	= "BPT's main purpose is providing a highly configurable eclipse bar with energy prediction to Balance druids. It's focused on using the CPU strictly necessary and no more, therefore, it's divided into several modules.",
						order = 2,
					},
					info4 = {
						type	= 'description',
						name	= "Energy track and prediction supported by LibBalancePowerTracker v"..select(1,LibBalancePowerTracker:GetVersion()).."."..select(2,LibBalancePowerTracker:GetVersion()),
						order = 3,
					},
					info = {
						type	= 'description',
						name	= "Created & maintained by Kurohoshi (EU - Minahonda)",
						order = 5,
					},
					info7 = {
						type	= 'description',
						name	= "Masque, MikSBT & LibSharedMedia are supported.",
						order = 5,
					},
					d1	= {
						type	= 'input',
						name	= "WoWinterface:",
						get		= function () return "www.wowinterface.com/downloads/info18000-BalancePowerTracker" end,
						set		= function() end,
						order	= 6,
						width	= "full"
					},
					d2	= {
						type	= 'input',
						name	= "Curse:",
						get		= function () return "www.curse.com/addons/wow/balancepowertracker" end,
						set		= function() end,
						order	= 7,
						width	= "full"
					},
				},
			},
		}, 
	} 

	LibStub("AceConfig-3.0"):RegisterOptionsTable("BalancePowerTracker", options,nil)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("BalancePowerTracker","BalancePowerTracker")
end

local frame = CreateFrame("Frame",nil,UIParent)
frame:SetScript("OnEvent",CreateOptions)
frame:RegisterEvent("ADDON_LOADED");